@@ -1,16 +1,17 @@
-from tensorflow import keras
 import tensorflow as tf
+from tensorflow import keras
 
 
 class NegativeLogLikelihood(keras.losses.Loss):
-    """
-    Marginalizes logits over last dimension so that it computes :math:`-\log(p(X))`. This can be
-    used for unsupervised generative learning.
+    r"""
+    Marginalize logits over last dimension so that it computes :math:`-\log(p(X))`.
+
+    This can be used for unsupervised generative learning.
     """
 
-    def call(self, _, y_pred):
-        """
-        Computes generative loss for optimizing :math:`\log(p(X))`
+    def call(self, _: tf.Tensor, y_pred: tf.Tensor) -> tf.Tensor:
+        r"""
+        Compute generative loss for optimizing :math:`\log(p(X))`.
 
         Args:
             _: True labels, ignored, but still provided to preserve Keras compatibility
@@ -19,5 +20,4 @@ class NegativeLogLikelihood(keras.losses.Loss):
         Returns:
             A `Tensor` that describes a generative unsupervised loss.
         """
-
         return -tf.reduce_logsumexp(y_pred, axis=1)
